@@ -218,7 +218,7 @@ class VerifyToken:
             'permission_list': permission_list, 'is_all_data': is_all_data}
         return permission_status
 
-    def filter_verify(self, group_list, is_all_data, user_name):
+    def filter_verify(self, group_list, is_all_data, user_name, user_field_name='creator'):
         """
         根据用户分组权限，个人权限，用户信息。整理出符合mongo塞选语句的权限赛选条件
         用户实际业务模块直接塞选出符合权限要求的数据
@@ -235,6 +235,6 @@ class VerifyToken:
         else:
             handle_abnormal(message='用户无任何群组权限，无法操作数据', status=403)
         if not is_all_data:
-            auth_filter.update(creator=user_name)
+            auth_filter.update({user_field_name: user_name})
 
         return auth_filter
\ No newline at end of file
